/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2017 Organizational file and create a SAS dataset.                                     *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer, replacing the '.' with the *
* folder path location (e.g. 'C:\temp') .                                                *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located, replacing the '.' with the folder   *
* path location (e.g. 'C:\temp') .                                                       *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\corp17nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = corp17nid ;

DATA library.&dataset ;
INFILE datafile LRECL=2100;
INPUT
   ACCEPT  1-2              BOOKER2  3               BOOKER3  4            
   BOOKERCD  5-6            BUSCLAS  7-10            CANTPAY  11           
   CCULPSCO  12-13          CH2APP  14               CH8FINGD  15          
   CMSRVORD  16             COFI  17                 COMPLY  18            
   COMPLYPR  19             CRIMPURP  20             DETBFINE  21          
   DISPOSIT  22             EMPLOYNM  23             FCULPSCO  24-25       
   FRAUDTYP  26-27          FINSTDS  28              HISTORY  29           
   HSMISCND  30             INCORLOC  31             INCORPYR  32-35       
   INDICT  36               INPLEA1  37              INPLEA2  38           
   INPLEA3  39              INPLEA4  40              INPLEA5  41           
   INPLEA6  42              INPLEA7  43              INPLEA8  44           
   INPLEA9  45              INPLEA10  46             INPLEA11  47          
   INPLEA12  48             INNOPL1  49              INNOPL2  50           
   INNOPL3  51              INNOPL4  52              INNOPL5  53           
   INNOPL6  54              INNOPL7  55              INNOPL8  56           
   INNOPL9  57              INNOPL10  58             INNOPL11  59          
   INNOPL12  60             JANDC  61                NEWCNVTN  62          
   NOCOMP  63               NOCOUNTS  64-65          NOREAVAR  66          
   NOUSTAT  67              OBSTRUCT  68             OFFLVL  69-70         
   ORDERCE  71              ORGTYPE  72              OWNSTRCT  73-74       
   PLEA  75                 PRIMOFF  76-77           PRCIVIL  78           
   PRCRIME  79              PROBATN  80-81           PROBMON  82           
   PSR  83                  QUARTER  84              REAS1  85-88          
   REAS2  89-91             REAS3  92-93             REAS4  94-96          
   REASON3  97              REASON4  98              REASONS  99           
   REMEDORD  100-103        SELFREP  104             SOURCES  105          
   TOLERNCE  106            TYPEOTHS  107-108        VICTNOTE  109         
   VIOLATE  110             AMENDYR  111-114         SENTYR  115-118       
   BASEFINE  119-128        COSTASSM  129-131        DISGORGE  132-136     
   FINOFFST  137-140        FORFEITR  141-149        GLFINMAX  150-160     
   GLFINMIN  161-171        STATMIN  172             STATMAX  173-182      
   RESTCAT  183             FINECAT  184             SUSFNCAT  185         
   LCAT1  186               LCAT2  187               LCATHI  188           
   LCATS1  189              LCATS2  190              LCATSHI  191          
   LCATR1  192              LCATR2  193              LCATRHI  194          
   LCATC1  195              LCATC2  196              LCATCHI  197          
   LCATU1  198              LCATU2  199              LCATUHI  200          
   CPIDN  201-207           BUSTEXT $ 208-248        FINSTXT $ 249-252     
   OWNSTEXT $ 253-266       PRMONTXT $ 267-362       ORDERTXT $ 363-549    
   TYPEOTTX $ 550-680       MINFINML  681-683        MAXFINML  684-686     
   ADJOFL1  687-688         ADJOFL2  689-690         ADJOFLHI  691-692     
   ADJ_B1  693-694          ADJ_B2  695-696          ADJ_BHI  697-698      
   ADJ_C1  699-700          ADJ_C2  701-702          ADJ_CHI  703-704      
   ADJ_D1  705              ADJ_D2  706              ADJ_DHI  707          
   ADJ_E1  708              ADJ_E2  709              ADJ_EHI  710          
   ADJ_F1  711              ADJ_F2  712              ADJ_FHI  713          
   ADJ_G1  714              ADJ_G2  715              ADJ_GHI  716          
   ADJ_H1  717              ADJ_H2  718              ADJ_HHI  719          
   ADJ_I1  720              ADJ_I2  721              ADJ_IHI  722          
   ADJ_J1  723              ADJ_J2  724              ADJ_JHI  725          
   ADJ_K1  726              ADJ_K2  727              ADJ_KHI  728          
   ADJ_L1  729              ADJ_L2  730              ADJ_LHI  731          
   ADJ_M1  732              ADJ_M2  733              ADJ_MHI  734          
   ADJ_N1  735              ADJ_N2  736              ADJ_NHI  737          
   ADJ_O1  738              ADJ_O2  739              ADJ_OHI  740          
   ADJ_P1  741              ADJ_P2  742              ADJ_PHI  743          
   ADJ_Q1  744              ADJ_Q2  745              ADJ_QHI  746          
   ADJ_R1  747              ADJ_R2  748              ADJ_RHI  749          
   ADJ_S1  750              ADJ_S2  751              ADJ_SHI  752          
   ADJ_T1  753              ADJ_T2  754              ADJ_THI  755          
   BASADJ1  756             BASADJ2  757             BASADJHI  758         
   BASE1  759-760           BASE2  761-762           BASEHI  763-764       
   BASLN1  765              BASLN2  766              BASLNHI  767          
   ADJOFS1  768-769         ADJOFS2  770-771         ADJOFSHI  772-773     
   ADJS_B1  774-775         ADJS_B2  776-777         ADJS_BHI  778-779     
   ADJS_C1  780-781         ADJS_C2  782-783         ADJS_CHI  784-785     
   ADJS_D1  786             ADJS_D2  787             ADJS_DHI  788         
   ADJS_E1  789             ADJS_E2  790             ADJS_EHI  791         
   ADJS_F1  792             ADJS_F2  793             ADJS_FHI  794         
   ADJS_G1  795             ADJS_G2  796             ADJS_GHI  797         
   ADJS_H1  798             ADJS_H2  799             ADJS_HHI  800         
   ADJS_I1  801             ADJS_I2  802             ADJS_IHI  803         
   ADJS_J1  804             ADJS_J2  805             ADJS_JHI  806         
   ADJS_K1  807             ADJS_K2  808             ADJS_KHI  809         
   ADJS_L1  810             ADJS_L2  811             ADJS_LHI  812         
   ADJS_M1  813             ADJS_M2  814             ADJS_MHI  815         
   ADJS_N1  816             ADJS_N2  817             ADJS_NHI  818         
   ADJS_O1  819             ADJS_O2  820             ADJS_OHI  821         
   ADJS_P1  822             ADJS_P2  823             ADJS_PHI  824         
   ADJS_Q1  825             ADJS_Q2  826             ADJS_QHI  827         
   ADJS_R1  828             ADJS_R2  829             ADJS_RHI  830         
   ADJS_S1  831             ADJS_S2  832             ADJS_SHI  833         
   ADJS_T1  834             ADJS_T2  835             ADJS_THI  836         
   BASADS1  837             BASADS2  838             BASADSHI  839         
   BASES1  840-841          BASES2  842-843          BASESHI  844-845      
   BASLNS1  846             BASLNS2  847             BASLNSHI  848         
   ADJOFR1  849-850         ADJOFR2  851             ADJOFRHI  852-853     
   ADJR_B1  854-855         ADJR_B2  856             ADJR_BHI  857-858     
   ADJR_C1  859             ADJR_C2  860             ADJR_CHI  861         
   ADJR_D1  862             ADJR_D2  863             ADJR_DHI  864         
   ADJR_E1  865             ADJR_E2  866             ADJR_EHI  867         
   ADJR_F1  868             ADJR_F2  869             ADJR_FHI  870         
   ADJR_G1  871             ADJR_G2  872             ADJR_GHI  873         
   ADJR_H1  874             ADJR_H2  875             ADJR_HHI  876         
   ADJR_I1  877             ADJR_I2  878             ADJR_IHI  879         
   ADJR_J1  880             ADJR_J2  881             ADJR_JHI  882         
   ADJR_K1  883             ADJR_K2  884             ADJR_KHI  885         
   ADJR_L1  886             ADJR_L2  887             ADJR_LHI  888         
   ADJR_M1  889             ADJR_M2  890             ADJR_MHI  891         
   ADJR_N1  892             ADJR_N2  893             ADJR_NHI  894         
   ADJR_O1  895             ADJR_O2  896             ADJR_OHI  897         
   ADJR_P1  898             ADJR_P2  899             ADJR_PHI  900         
   ADJR_Q1  901             ADJR_Q2  902             ADJR_QHI  903         
   ADJR_R1  904             ADJR_R2  905             ADJR_RHI  906         
   ADJR_S1  907             ADJR_S2  908             ADJR_SHI  909         
   ADJR_T1  910             ADJR_T2  911             ADJR_THI  912         
   BASADR1  913             BASADR2  914             BASADRHI  915         
   BASER1  916-917          BASER2  918              BASERHI  919-920      
   BASLNR1  921             BASLNR2  922             BASLNRHI  923         
   ADJOFC1  924             ADJOFC2  925             ADJOFCHI  926         
   ADJC_B1  927             ADJC_B2  928             ADJC_BHI  929         
   ADJC_C1  930             ADJC_C2  931             ADJC_CHI  932         
   ADJC_D1  933             ADJC_D2  934             ADJC_DHI  935         
   ADJC_E1  936             ADJC_E2  937             ADJC_EHI  938         
   ADJC_F1  939             ADJC_F2  940             ADJC_FHI  941         
   ADJC_G1  942             ADJC_G2  943             ADJC_GHI  944         
   ADJC_H1  945             ADJC_H2  946             ADJC_HHI  947         
   ADJC_I1  948             ADJC_I2  949             ADJC_IHI  950         
   ADJC_J1  951             ADJC_J2  952             ADJC_JHI  953         
   ADJC_K1  954             ADJC_K2  955             ADJC_KHI  956         
   ADJC_L1  957             ADJC_L2  958             ADJC_LHI  959         
   ADJC_M1  960             ADJC_M2  961             ADJC_MHI  962         
   ADJC_N1  963             ADJC_N2  964             ADJC_NHI  965         
   ADJC_O1  966             ADJC_O2  967             ADJC_OHI  968         
   ADJC_P1  969             ADJC_P2  970             ADJC_PHI  971         
   ADJC_Q1  972             ADJC_Q2  973             ADJC_QHI  974         
   ADJC_R1  975             ADJC_R2  976             ADJC_RHI  977         
   ADJC_S1  978             ADJC_S2  979             ADJC_SHI  980         
   ADJC_T1  981             ADJC_T2  982             ADJC_THI  983         
   BASADC1  984             BASADC2  985             BASADCHI  986         
   BASEC1  987              BASEC2  988              BASECHI  989          
   BASLNC1  990             BASLNC2  991             BASLNCHI  992         
   ADJOFU1  993             ADJOFU2  994             ADJOFUHI  995         
   ADJU_B1  996             ADJU_B2  997             ADJU_BHI  998         
   ADJU_C1  999             ADJU_C2  1000            ADJU_CHI  1001        
   ADJU_D1  1002            ADJU_D2  1003            ADJU_DHI  1004        
   ADJU_E1  1005            ADJU_E2  1006            ADJU_EHI  1007        
   ADJU_F1  1008            ADJU_F2  1009            ADJU_FHI  1010        
   ADJU_G1  1011            ADJU_G2  1012            ADJU_GHI  1013        
   ADJU_H1  1014            ADJU_H2  1015            ADJU_HHI  1016        
   ADJU_I1  1017            ADJU_I2  1018            ADJU_IHI  1019        
   ADJU_J1  1020            ADJU_J2  1021            ADJU_JHI  1022        
   ADJU_K1  1023            ADJU_K2  1024            ADJU_KHI  1025        
   ADJU_L1  1026            ADJU_L2  1027            ADJU_LHI  1028        
   ADJU_M1  1029            ADJU_M2  1030            ADJU_MHI  1031        
   ADJU_N1  1032            ADJU_N2  1033            ADJU_NHI  1034        
   ADJU_O1  1035            ADJU_O2  1036            ADJU_OHI  1037        
   ADJU_P1  1038            ADJU_P2  1039            ADJU_PHI  1040        
   ADJU_Q1  1041            ADJU_Q2  1042            ADJU_QHI  1043        
   ADJU_R1  1044            ADJU_R2  1045            ADJU_RHI  1046        
   ADJU_S1  1047            ADJU_S2  1048            ADJU_SHI  1049        
   ADJU_T1  1050            ADJU_T2  1051            ADJU_THI  1052        
   BASADU1  1053            BASADU2  1054            BASADUHI  1055        
   BASEU1  1056             BASEU2  1057             BASEUHI  1058         
   BASLNU1  1059            BASLNU2  1060            BASLNUHI  1061        
   ADJL_B1 $ 1062           ADJL_B2 $ 1063           ADJL_BHI $ 1064       
   ADJL_C1 $ 1065-1066      ADJL_C2 $ 1067           ADJL_CHI $ 1068-1069  
   ADJL_D1 $ 1070           ADJL_D2 $ 1071           ADJL_DHI $ 1072       
   ADJL_E1 $ 1073           ADJL_E2 $ 1074           ADJL_EHI $ 1075       
   ADJL_F1 $ 1076           ADJL_F2 $ 1077           ADJL_FHI $ 1078       
   ADJL_G1 $ 1079           ADJL_G2 $ 1080           ADJL_GHI $ 1081       
   ADJL_H1 $ 1082-1083      ADJL_H2 $ 1084           ADJL_HHI $ 1085-1086  
   ADJL_I1 $ 1087           ADJL_I2 $ 1088           ADJL_IHI $ 1089       
   ADJL_J1 $ 1090           ADJL_J2 $ 1091           ADJL_JHI $ 1092       
   ADJL_K1 $ 1093           ADJL_K2 $ 1094           ADJL_KHI $ 1095       
   ADJL_L1 $ 1096           ADJL_L2 $ 1097           ADJL_LHI $ 1098       
   ADJL_M1 $ 1099           ADJL_M2 $ 1100           ADJL_MHI $ 1101       
   ADJL_N1 $ 1102           ADJL_N2 $ 1103           ADJL_NHI $ 1104       
   ADJL_O1 $ 1105           ADJL_O2 $ 1106           ADJL_OHI $ 1107       
   ADJL_P1 $ 1108           ADJL_P2 $ 1109           ADJL_PHI $ 1110       
   ADJL_Q1 $ 1111           ADJL_Q2 $ 1112           ADJL_QHI $ 1113       
   ADJL_R1 $ 1114           ADJL_R2 $ 1115           ADJL_RHI $ 1116       
   ADJL_S1 $ 1117           ADJL_S2 $ 1118           ADJL_SHI $ 1119       
   ADJL_T1 $ 1120           ADJL_T2 $ 1121           ADJL_THI $ 1122       
   BASEL1 $ 1123            BASEL2 $ 1124            BASELHI $ 1125        
   ADSL_B1 $ 1126           ADSL_B2 $ 1127           ADSL_BHI $ 1128       
   ADSL_C1 $ 1129-1130      ADSL_C2 $ 1131           ADSL_CHI $ 1132-1133  
   ADSL_D1 $ 1134           ADSL_D2 $ 1135           ADSL_DHI $ 1136       
   ADSL_E1 $ 1137           ADSL_E2 $ 1138           ADSL_EHI $ 1139       
   ADSL_F1 $ 1140           ADSL_F2 $ 1141           ADSL_FHI $ 1142       
   ADSL_G1 $ 1143           ADSL_G2 $ 1144           ADSL_GHI $ 1145       
   ADSL_H1 $ 1146-1147      ADSL_H2 $ 1148           ADSL_HHI $ 1149-1150  
   ADSL_I1 $ 1151           ADSL_I2 $ 1152           ADSL_IHI $ 1153       
   ADSL_J1 $ 1154           ADSL_J2 $ 1155           ADSL_JHI $ 1156       
   ADSL_K1 $ 1157           ADSL_K2 $ 1158           ADSL_KHI $ 1159       
   ADSL_L1 $ 1160           ADSL_L2 $ 1161           ADSL_LHI $ 1162       
   ADSL_M1 $ 1163           ADSL_M2 $ 1164           ADSL_MHI $ 1165       
   ADSL_N1 $ 1166           ADSL_N2 $ 1167           ADSL_NHI $ 1168       
   ADSL_O1 $ 1169           ADSL_O2 $ 1170           ADSL_OHI $ 1171       
   ADSL_P1 $ 1172           ADSL_P2 $ 1173           ADSL_PHI $ 1174       
   ADSL_Q1 $ 1175           ADSL_Q2 $ 1176           ADSL_QHI $ 1177       
   ADSL_R1 $ 1178           ADSL_R2 $ 1179           ADSL_RHI $ 1180       
   ADSL_S1 $ 1181           ADSL_S2 $ 1182           ADSL_SHI $ 1183       
   ADSL_T1 $ 1184           ADSL_T2 $ 1185           ADSL_THI $ 1186       
   BASESL1 $ 1187           BASESL2 $ 1188           BASESLHI $ 1189       
   ADRL_B1 $ 1190           ADRL_B2 $ 1191           ADRL_BHI $ 1192       
   ADRL_C1 $ 1193-1194      ADRL_C2 $ 1195           ADRL_CHI $ 1196-1197  
   ADRL_D1 $ 1198           ADRL_D2 $ 1199           ADRL_DHI $ 1200       
   ADRL_E1 $ 1201           ADRL_E2 $ 1202           ADRL_EHI $ 1203       
   ADRL_F1 $ 1204           ADRL_F2 $ 1205           ADRL_FHI $ 1206       
   ADRL_G1 $ 1207           ADRL_G2 $ 1208           ADRL_GHI $ 1209       
   ADRL_H1 $ 1210           ADRL_H2 $ 1211           ADRL_HHI $ 1212       
   ADRL_I1 $ 1213           ADRL_I2 $ 1214           ADRL_IHI $ 1215       
   ADRL_J1 $ 1216           ADRL_J2 $ 1217           ADRL_JHI $ 1218       
   ADRL_K1 $ 1219           ADRL_K2 $ 1220           ADRL_KHI $ 1221       
   ADRL_L1 $ 1222           ADRL_L2 $ 1223           ADRL_LHI $ 1224       
   ADRL_M1 $ 1225           ADRL_M2 $ 1226           ADRL_MHI $ 1227       
   ADRL_N1 $ 1228           ADRL_N2 $ 1229           ADRL_NHI $ 1230       
   ADRL_O1 $ 1231           ADRL_O2 $ 1232           ADRL_OHI $ 1233       
   ADRL_P1 $ 1234           ADRL_P2 $ 1235           ADRL_PHI $ 1236       
   ADRL_Q1 $ 1237           ADRL_Q2 $ 1238           ADRL_QHI $ 1239       
   ADRL_R1 $ 1240           ADRL_R2 $ 1241           ADRL_RHI $ 1242       
   ADRL_S1 $ 1243           ADRL_S2 $ 1244           ADRL_SHI $ 1245       
   ADRL_T1 $ 1246           ADRL_T2 $ 1247           ADRL_THI $ 1248       
   BASERL1 $ 1249           BASERL2 $ 1250           BASERLHI $ 1251       
   ADCL_B1 $ 1252           ADCL_B2 $ 1253           ADCL_BHI $ 1254       
   ADCL_C1 $ 1255           ADCL_C2 $ 1256           ADCL_CHI $ 1257       
   ADCL_D1 $ 1258           ADCL_D2 $ 1259           ADCL_DHI $ 1260       
   ADCL_E1 $ 1261           ADCL_E2 $ 1262           ADCL_EHI $ 1263       
   ADCL_F1 $ 1264           ADCL_F2 $ 1265           ADCL_FHI $ 1266       
   ADCL_G1 $ 1267           ADCL_G2 $ 1268           ADCL_GHI $ 1269       
   ADCL_H1 $ 1270           ADCL_H2 $ 1271           ADCL_HHI $ 1272       
   ADCL_I1 $ 1273           ADCL_I2 $ 1274           ADCL_IHI $ 1275       
   ADCL_J1 $ 1276           ADCL_J2 $ 1277           ADCL_JHI $ 1278       
   ADCL_K1 $ 1279           ADCL_K2 $ 1280           ADCL_KHI $ 1281       
   ADCL_L1 $ 1282           ADCL_L2 $ 1283           ADCL_LHI $ 1284       
   ADCL_M1 $ 1285           ADCL_M2 $ 1286           ADCL_MHI $ 1287       
   ADCL_N1 $ 1288           ADCL_N2 $ 1289           ADCL_NHI $ 1290       
   ADCL_O1 $ 1291           ADCL_O2 $ 1292           ADCL_OHI $ 1293       
   ADCL_P1 $ 1294           ADCL_P2 $ 1295           ADCL_PHI $ 1296       
   ADCL_Q1 $ 1297           ADCL_Q2 $ 1298           ADCL_QHI $ 1299       
   ADCL_R1 $ 1300           ADCL_R2 $ 1301           ADCL_RHI $ 1302       
   ADCL_S1 $ 1303           ADCL_S2 $ 1304           ADCL_SHI $ 1305       
   ADCL_T1 $ 1306           ADCL_T2 $ 1307           ADCL_THI $ 1308       
   BASECL1 $ 1309           BASECL2 $ 1310           BASECLHI $ 1311       
   ADUL_B1 $ 1312           ADUL_B2 $ 1313           ADUL_BHI $ 1314       
   ADUL_C1 $ 1315           ADUL_C2 $ 1316           ADUL_CHI $ 1317       
   ADUL_D1 $ 1318           ADUL_D2 $ 1319           ADUL_DHI $ 1320       
   ADUL_E1 $ 1321           ADUL_E2 $ 1322           ADUL_EHI $ 1323       
   ADUL_F1 $ 1324           ADUL_F2 $ 1325           ADUL_FHI $ 1326       
   ADUL_G1 $ 1327           ADUL_G2 $ 1328           ADUL_GHI $ 1329       
   ADUL_H1 $ 1330           ADUL_H2 $ 1331           ADUL_HHI $ 1332       
   ADUL_I1 $ 1333           ADUL_I2 $ 1334           ADUL_IHI $ 1335       
   ADUL_J1 $ 1336           ADUL_J2 $ 1337           ADUL_JHI $ 1338       
   ADUL_K1 $ 1339           ADUL_K2 $ 1340           ADUL_KHI $ 1341       
   ADUL_L1 $ 1342           ADUL_L2 $ 1343           ADUL_LHI $ 1344       
   ADUL_M1 $ 1345           ADUL_M2 $ 1346           ADUL_MHI $ 1347       
   ADUL_N1 $ 1348           ADUL_N2 $ 1349           ADUL_NHI $ 1350       
   ADUL_O1 $ 1351           ADUL_O2 $ 1352           ADUL_OHI $ 1353       
   ADUL_P1 $ 1354           ADUL_P2 $ 1355           ADUL_PHI $ 1356       
   ADUL_Q1 $ 1357           ADUL_Q2 $ 1358           ADUL_QHI $ 1359       
   ADUL_R1 $ 1360           ADUL_R2 $ 1361           ADUL_RHI $ 1362       
   ADUL_S1 $ 1363           ADUL_S2 $ 1364           ADUL_SHI $ 1365       
   ADUL_T1 $ 1366           ADUL_T2 $ 1367           ADUL_THI $ 1368       
   BASEUL1 $ 1369           BASEUL2 $ 1370           BASEULHI $ 1371       
   GDLINE1 $ 1372-1376      GDLINE2 $ 1377-1381      GDSTAT1 $ 1382-1386   
   GDSTAT2 $ 1387-1391      GDREF1 $ 1392-1396       GDREF2 $ 1397         
   GDCROS1 $ 1398           GDCROS2 $ 1399           GDUNDR1 $ 1400        
   GDUNDR2 $ 1401           GDLINEHI $ 1402-1406     GDSTATHI $ 1407-1411  
   GDREFHI $ 1412-1416      GDCROSHI $ 1417          GDUNDRHI $ 1418       
   STA1_1 $ 1419-1432       STA1_2 $ 1433-1442       STA1_3 $ 1443-1454    
   STA1_4 $ 1455-1463       STA1_5 $ 1464-1472       STA1_6 $ 1473-1481    
   STA1_7 $ 1482-1490       STA1_8 $ 1491-1498       STA1_9 $ 1499-1507    
   STA1_10 $ 1508-1513      STA1_11 $ 1514-1519      STA1_12 $ 1520-1525   
   STA1_13 $ 1526-1531      STA1_14 $ 1532-1537      STA1_15 $ 1538-1543   
   STA1_16 $ 1544-1549      STA1_17 $ 1550-1555      STA1_18 $ 1556-1561   
   STA1_19 $ 1562-1567      STA1_20 $ 1568-1573      STA1_21 $ 1574-1579   
   STA1_22 $ 1580-1585      STA1_23 $ 1586-1591      STA1_24 $ 1592-1597   
   STA2_1 $ 1598-1609       STA2_2 $ 1610-1618       STA2_3 $ 1619-1630    
   STA2_4 $ 1631-1639       STA2_5 $ 1640-1648       STA2_6 $ 1649-1657    
   STA2_7 $ 1658-1665       STA2_8 $ 1666-1668       STA2_9 $ 1669-1676    
   STA2_10 $ 1677-1682      STA2_11 $ 1683-1688      STA2_12 $ 1689-1694   
   STA2_13 $ 1695-1697      STA2_14 $ 1698-1700      STA2_15 $ 1701-1703   
   STA2_16 $ 1704-1706      STA2_17 $ 1707-1709      STA2_18 $ 1710-1712   
   STA2_19 $ 1713-1715      STA2_20 $ 1716-1718      STA2_21 $ 1719-1721   
   STA2_22 $ 1722-1724      STA2_23 $ 1725-1727      STA2_24 $ 1728-1730   
   STA3_1 $ 1731-1739       STA3_2 $ 1740-1748       STA3_3 $ 1749-1757    
   STA3_4 $ 1758-1766       STA3_5 $ 1767-1773       STA3_6 $ 1774-1776    
   STA3_7 $ 1777-1779       STA3_8 $ 1780            STA3_9 $ 1781         
   STA3_10 $ 1782           STA3_11 $ 1783           STA3_12 $ 1784        
   STA3_13 $ 1785           STA3_14 $ 1786           STA3_15 $ 1787        
   STA3_16 $ 1788           STA3_17 $ 1789           STA3_18 $ 1790        
   STA3_19 $ 1791           STA3_20 $ 1792           STA3_21 $ 1793        
   STA3_22 $ 1794           STA3_23 $ 1795           STA3_24 $ 1796        
   NWSTAT1 $ 1797-1810      NWSTAT2 $ 1811-1822      NWSTAT3 $ 1823-1834   
   NWSTAT4 $ 1835-1844      NWSTAT5 $ 1845-1853      NWSTAT6 $ 1854-1861   
   NWSTAT7 $ 1862-1868      NWSTAT8 $ 1869-1876      SMAX1  1877-1886      
   SMAX2  1887-1896         SMAX3  1897-1906         SMAX4  1907-1912      
   SMAX5  1913-1918         SMAX6  1919-1924         SMAX7  1925-1930      
   SMAX8  1931-1936         SMAX9  1937-1942         SMAX10  1943-1948     
   SMAX11  1949-1954        SMAX12  1955-1960        SMAX13  1961-1966     
   SMAX14  1967-1972        SMAX15  1973-1978        SMAX16  1979-1984     
   SMAX17  1985-1990        SMAX18  1991-1996        SMAX19  1997-2002     
   SMAX20  2003-2008        SMAX21  2009-2014        SMAX22  2015-2020     
   SMAX23  2021-2026        SMAX24  2027-2032        SMIN1  2033           
   SMIN2  2034              SMIN3  2035              SMIN4  2036           
   SMIN5  2037              SMIN6  2038              SMIN7  2039           
   SMIN8  2040              SMIN9  2041              SMIN10  2042          
   SMIN11  2043             SMIN12  2044             SMIN13  2045          
   SMIN14  2046             SMIN15  2047             SMIN16  2048          
   SMIN17  2049             SMIN18  2050             SMIN19  2051          
   SMIN20  2052             SMIN21  2053             SMIN22  2054          
   SMIN23  2055             SMIN24  2056             RETEXT1 $ 2057-2097   
   RETEXT2 $ 2098           RETEXT3 $ 2099           RETEXT4 $ 2100        
 ;                       

LABEL
   ACCEPT = "ACCEPT"
   BUSCLAS = "BUSCLAS"
   CANTPAY = "CANTPAY"
   CCULPSCO = "CCULPSCO"
   CH2APP = "CH2APP"
   CH8FINGD = "CH8FINGD"
   CMSRVORD = "CMSRVORD"
   COFI = "COFI"
   COMPLY = "COMPLY"
   COMPLYPR = "COMPLYPR"
   CRIMPURP = "CRIMPURP"
   DETBFINE = "DETBFINE"
   DISPOSIT = "DISPOSIT"
   EMPLOYNM = "FTEMNUM"
   FCULPSCO = "FCULPSCO"
   FRAUDTYP = "FRAUDTYP"
   FINSTDS = "FINSTDS"
   HISTORY = "HISTORY"
   HSMISCND = "HSMISCND"
   INCORLOC = "INCORLOC"
   INCORPYR = "INCORPYR"
   INDICT = "INDICT"
   JANDC = "JANDC"
   NOCOUNTS = "NOCOUNTS"
   OBSTRUCT = "OBSTRUCT"
   OFFLVL = "OFFLVL"
   ORDERCE = "ORDERCE"
   ORGTYPE = "ORGTYPE"
   PLEA = "PLEA"
   PRIMOFF = "OFFTYPE"
   PRCIVIL = "PRCIVIL"
   PRCRIME = "PRCRIME"
   PROBATN = "PROBATN"
   PROBMON = "PROBMON"
   PSR = "PSR"
   REASON3 = "REASON3"
   REASON4 = "REASON4"
   REASONS = "REASONS"
   REMEDORD = "REMEDORD"
   SELFREP = "SELFREP"
   SOURCES = "SOURCES"
   TOLERNCE = "TOLERNCE"
   TYPEOTHS = "TYPEOTHS"
   VICTNOTE = "VICTNOTE"
   VIOLATE = "VIOLATE"
   AMENDYR = "AMENDYR"
   BASEFINE = "BASEFINE"
   COSTASSM = "COSTASSM"
   DISGORGE = "DISGORGE"
   FINOFFST = "FINOFFST"
   FORFEITR = "FORFEITR"
   GLFINMAX = "GLFINMAX"
   GLFINMIN = "GLFINMIN"
   CPIDN = "CPIDN"
   BUSTEXT = "BUSTEXT"
   FINSTXT = "FINSTXT"
   OWNSTEXT = "OWNSTEXT"
   PRMONTXT = "PRMONTXT"
   ORDERTXT = "ORDERTXT"
   TYPEOTTX = "TYPOTXT"
   MINFINML = "MINFINML"
   MAXFINML = "MAXFINML"
;

LENGTH
   ACCEPT 3                 BOOKER2 3                BOOKER3 3             
   BOOKERCD 3               BUSCLAS 4                CANTPAY 3             
   CCULPSCO 3               CH2APP 3                 CH8FINGD 3            
   CMSRVORD 3               COFI 3                   COMPLY 3              
   COMPLYPR 3               CRIMPURP 3               DETBFINE 3            
   DISPOSIT 3               EMPLOYNM 3               FCULPSCO 3            
   FRAUDTYP 3               FINSTDS 3                HISTORY 3             
   HSMISCND 3               INCORLOC 3               INCORPYR 4            
   INDICT 3                 INPLEA1 3                INPLEA2 3             
   INPLEA3 3                INPLEA4 3                INPLEA5 3             
   INPLEA6 3                INPLEA7 3                INPLEA8 3             
   INPLEA9 3                INPLEA10 3               INPLEA11 3            
   INPLEA12 3               INNOPL1 3                INNOPL2 3             
   INNOPL3 3                INNOPL4 3                INNOPL5 3             
   INNOPL6 3                INNOPL7 3                INNOPL8 3             
   INNOPL9 3                INNOPL10 3               INNOPL11 3            
   INNOPL12 3               JANDC 3                  NEWCNVTN 3            
   NOCOMP 3                 NOCOUNTS 3               NOREAVAR 3            
   NOUSTAT 3                OBSTRUCT 3               OFFLVL 3              
   ORDERCE 3                ORGTYPE 3                OWNSTRCT 3            
   PLEA 3                   PRIMOFF 3                PRCIVIL 3             
   PRCRIME 3                PROBATN 3                PROBMON 3             
   PSR 3                    QUARTER 3                REAS1 4               
   REAS2 4                  REAS3 3                  REAS4 4               
   REASON3 3                REASON4 3                REASONS 3             
   REMEDORD 4               SELFREP 3                SOURCES 3             
   TOLERNCE 3               TYPEOTHS 3               VICTNOTE 3            
   VIOLATE 3                AMENDYR 4                SENTYR 4              
   COSTASSM 4               DISGORGE 4               FINOFFST 4            
   FORFEITR 6               STATMIN 3                RESTCAT 3             
   FINECAT 3                SUSFNCAT 3               LCAT1 3               
   LCAT2 3                  LCATHI 3                 LCATS1 3              
   LCATS2 3                 LCATSHI 3                LCATR1 3              
   LCATR2 3                 LCATRHI 3                LCATC1 3              
   LCATC2 3                 LCATCHI 3                LCATU1 3              
   LCATU2 3                 LCATUHI 3                CPIDN 6               
   ADJOFL1 3                ADJOFL2 3                ADJOFLHI 3            
   ADJ_B1 3                 ADJ_B2 3                 ADJ_BHI 3             
   ADJ_C1 3                 ADJ_C2 3                 ADJ_CHI 3             
   ADJ_D1 3                 ADJ_D2 3                 ADJ_DHI 3             
   ADJ_E1 3                 ADJ_E2 3                 ADJ_EHI 3             
   ADJ_F1 3                 ADJ_F2 3                 ADJ_FHI 3             
   ADJ_G1 3                 ADJ_G2 3                 ADJ_GHI 3             
   ADJ_H1 3                 ADJ_H2 3                 ADJ_HHI 3             
   ADJ_I1 3                 ADJ_I2 3                 ADJ_IHI 3             
   ADJ_J1 3                 ADJ_J2 3                 ADJ_JHI 3             
   ADJ_K1 3                 ADJ_K2 3                 ADJ_KHI 3             
   ADJ_L1 3                 ADJ_L2 3                 ADJ_LHI 3             
   ADJ_M1 3                 ADJ_M2 3                 ADJ_MHI 3             
   ADJ_N1 3                 ADJ_N2 3                 ADJ_NHI 3             
   ADJ_O1 3                 ADJ_O2 3                 ADJ_OHI 3             
   ADJ_P1 3                 ADJ_P2 3                 ADJ_PHI 3             
   ADJ_Q1 3                 ADJ_Q2 3                 ADJ_QHI 3             
   ADJ_R1 3                 ADJ_R2 3                 ADJ_RHI 3             
   ADJ_S1 3                 ADJ_S2 3                 ADJ_SHI 3             
   ADJ_T1 3                 ADJ_T2 3                 ADJ_THI 3             
   BASADJ1 3                BASADJ2 3                BASADJHI 3            
   BASE1 3                  BASE2 3                  BASEHI 3              
   BASLN1 3                 BASLN2 3                 BASLNHI 3             
   ADJOFS1 3                ADJOFS2 3                ADJOFSHI 3            
   ADJS_B1 3                ADJS_B2 3                ADJS_BHI 3            
   ADJS_C1 3                ADJS_C2 3                ADJS_CHI 3            
   ADJS_D1 3                ADJS_D2 3                ADJS_DHI 3            
   ADJS_E1 3                ADJS_E2 3                ADJS_EHI 3            
   ADJS_F1 3                ADJS_F2 3                ADJS_FHI 3            
   ADJS_G1 3                ADJS_G2 3                ADJS_GHI 3            
   ADJS_H1 3                ADJS_H2 3                ADJS_HHI 3            
   ADJS_I1 3                ADJS_I2 3                ADJS_IHI 3            
   ADJS_J1 3                ADJS_J2 3                ADJS_JHI 3            
   ADJS_K1 3                ADJS_K2 3                ADJS_KHI 3            
   ADJS_L1 3                ADJS_L2 3                ADJS_LHI 3            
   ADJS_M1 3                ADJS_M2 3                ADJS_MHI 3            
   ADJS_N1 3                ADJS_N2 3                ADJS_NHI 3            
   ADJS_O1 3                ADJS_O2 3                ADJS_OHI 3            
   ADJS_P1 3                ADJS_P2 3                ADJS_PHI 3            
   ADJS_Q1 3                ADJS_Q2 3                ADJS_QHI 3            
   ADJS_R1 3                ADJS_R2 3                ADJS_RHI 3            
   ADJS_S1 3                ADJS_S2 3                ADJS_SHI 3            
   ADJS_T1 3                ADJS_T2 3                ADJS_THI 3            
   BASADS1 3                BASADS2 3                BASADSHI 3            
   BASES1 3                 BASES2 3                 BASESHI 3             
   BASLNS1 3                BASLNS2 3                BASLNSHI 3            
   ADJOFR1 3                ADJOFR2 3                ADJOFRHI 3            
   ADJR_B1 3                ADJR_B2 3                ADJR_BHI 3            
   ADJR_C1 3                ADJR_C2 3                ADJR_CHI 3            
   ADJR_D1 3                ADJR_D2 3                ADJR_DHI 3            
   ADJR_E1 3                ADJR_E2 3                ADJR_EHI 3            
   ADJR_F1 3                ADJR_F2 3                ADJR_FHI 3            
   ADJR_G1 3                ADJR_G2 3                ADJR_GHI 3            
   ADJR_H1 3                ADJR_H2 3                ADJR_HHI 3            
   ADJR_I1 3                ADJR_I2 3                ADJR_IHI 3            
   ADJR_J1 3                ADJR_J2 3                ADJR_JHI 3            
   ADJR_K1 3                ADJR_K2 3                ADJR_KHI 3            
   ADJR_L1 3                ADJR_L2 3                ADJR_LHI 3            
   ADJR_M1 3                ADJR_M2 3                ADJR_MHI 3            
   ADJR_N1 3                ADJR_N2 3                ADJR_NHI 3            
   ADJR_O1 3                ADJR_O2 3                ADJR_OHI 3            
   ADJR_P1 3                ADJR_P2 3                ADJR_PHI 3            
   ADJR_Q1 3                ADJR_Q2 3                ADJR_QHI 3            
   ADJR_R1 3                ADJR_R2 3                ADJR_RHI 3            
   ADJR_S1 3                ADJR_S2 3                ADJR_SHI 3            
   ADJR_T1 3                ADJR_T2 3                ADJR_THI 3            
   BASADR1 3                BASADR2 3                BASADRHI 3            
   BASER1 3                 BASER2 3                 BASERHI 3             
   BASLNR1 3                BASLNR2 3                BASLNRHI 3            
   ADJOFC1 3                ADJOFC2 3                ADJOFCHI 3            
   ADJC_B1 3                ADJC_B2 3                ADJC_BHI 3            
   ADJC_C1 3                ADJC_C2 3                ADJC_CHI 3            
   ADJC_D1 3                ADJC_D2 3                ADJC_DHI 3            
   ADJC_E1 3                ADJC_E2 3                ADJC_EHI 3            
   ADJC_F1 3                ADJC_F2 3                ADJC_FHI 3            
   ADJC_G1 3                ADJC_G2 3                ADJC_GHI 3            
   ADJC_H1 3                ADJC_H2 3                ADJC_HHI 3            
   ADJC_I1 3                ADJC_I2 3                ADJC_IHI 3            
   ADJC_J1 3                ADJC_J2 3                ADJC_JHI 3            
   ADJC_K1 3                ADJC_K2 3                ADJC_KHI 3            
   ADJC_L1 3                ADJC_L2 3                ADJC_LHI 3            
   ADJC_M1 3                ADJC_M2 3                ADJC_MHI 3            
   ADJC_N1 3                ADJC_N2 3                ADJC_NHI 3            
   ADJC_O1 3                ADJC_O2 3                ADJC_OHI 3            
   ADJC_P1 3                ADJC_P2 3                ADJC_PHI 3            
   ADJC_Q1 3                ADJC_Q2 3                ADJC_QHI 3            
   ADJC_R1 3                ADJC_R2 3                ADJC_RHI 3            
   ADJC_S1 3                ADJC_S2 3                ADJC_SHI 3            
   ADJC_T1 3                ADJC_T2 3                ADJC_THI 3            
   BASADC1 3                BASADC2 3                BASADCHI 3            
   BASEC1 3                 BASEC2 3                 BASECHI 3             
   BASLNC1 3                BASLNC2 3                BASLNCHI 3            
   ADJOFU1 3                ADJOFU2 3                ADJOFUHI 3            
   ADJU_B1 3                ADJU_B2 3                ADJU_BHI 3            
   ADJU_C1 3                ADJU_C2 3                ADJU_CHI 3            
   ADJU_D1 3                ADJU_D2 3                ADJU_DHI 3            
   ADJU_E1 3                ADJU_E2 3                ADJU_EHI 3            
   ADJU_F1 3                ADJU_F2 3                ADJU_FHI 3            
   ADJU_G1 3                ADJU_G2 3                ADJU_GHI 3            
   ADJU_H1 3                ADJU_H2 3                ADJU_HHI 3            
   ADJU_I1 3                ADJU_I2 3                ADJU_IHI 3            
   ADJU_J1 3                ADJU_J2 3                ADJU_JHI 3            
   ADJU_K1 3                ADJU_K2 3                ADJU_KHI 3            
   ADJU_L1 3                ADJU_L2 3                ADJU_LHI 3            
   ADJU_M1 3                ADJU_M2 3                ADJU_MHI 3            
   ADJU_N1 3                ADJU_N2 3                ADJU_NHI 3            
   ADJU_O1 3                ADJU_O2 3                ADJU_OHI 3            
   ADJU_P1 3                ADJU_P2 3                ADJU_PHI 3            
   ADJU_Q1 3                ADJU_Q2 3                ADJU_QHI 3            
   ADJU_R1 3                ADJU_R2 3                ADJU_RHI 3            
   ADJU_S1 3                ADJU_S2 3                ADJU_SHI 3            
   ADJU_T1 3                ADJU_T2 3                ADJU_THI 3            
   BASADU1 3                BASADU2 3                BASADUHI 3            
   BASEU1 3                 BASEU2 3                 BASEUHI 3             
   BASLNU1 3                BASLNU2 3                BASLNUHI 3            
   SMAX1 6                  SMAX2 6                  SMAX3 6               
   SMAX4 6                  SMAX5 6                  SMAX6 6               
   SMAX7 6                  SMAX8 6                  SMAX9 6               
   SMAX10 6                 SMAX11 6                 SMAX12 6              
   SMAX13 6                 SMAX14 6                 SMAX15 6              
   SMAX16 6                 SMAX17 6                 SMAX18 6              
   SMAX19 6                 SMAX20 6                 SMAX21 6              
   SMAX22 6                 SMAX23 6                 SMAX24 6              
   SMIN1 3                  SMIN2 3                  SMIN3 3               
   SMIN4 3                  SMIN5 3                  SMIN6 3               
   SMIN7 3                  SMIN8 3                  SMIN9 3               
   SMIN10 3                 SMIN11 3                 SMIN12 3              
   SMIN13 3                 SMIN14 3                 SMIN15 3              
   SMIN16 3                 SMIN17 3                 SMIN18 3              
   SMIN19 3                 SMIN20 3                 SMIN21 3              
   SMIN22 3                 SMIN23 3                 SMIN24 3 ;

        

RUN ;
